# Common functionality for GCNU libraries

The functionality provided in this repository is used by libraries developed at the Gatsby Computational Neuroscience Unit. For example, this functionality is used in  the [Sparse Variational Gaussian Process Factor Analysis](https://github.com/joacorapela/svGPFA)) repository.
